Index: net/log/test_net_log.h |
diff --git a/net/log/capturing_net_log.h b/net/log/test_net_log.h |
similarity index 77% |
rename from net/log/capturing_net_log.h |
rename to net/log/test_net_log.h |
index f2cc03f7bc620f4c760c67039a2f93313cee8616..35bee52b6f3b1f0677a60cc332ca734c3c20d657 100644 |
--- a/net/log/capturing_net_log.h |
+++ b/net/log/test_net_log.h |
@@ -16,17 +16,17 @@ |
namespace net { |
// CapturingNetLog is convenience class which combines a NetLog and a |
// CapturingNetLogObserver. It is intended for testing only, and is part of the |
// net_test_support project. |
-class CapturingNetLog : public NetLog { |
+class TestNetLog : public NetLog { |
public: |
// TODO(mmenke): Get rid of these. |
typedef CapturedNetLogEntry CapturedEntry; |
typedef CapturedNetLogEntry::List CapturedEntryList; |
- CapturingNetLog(); |
- ~CapturingNetLog() override; |
+ TestNetLog(); |
+ ~TestNetLog() override; |
void SetLogLevel(LogLevel log_level); |
@@ -39,11 +39,11 @@ class CapturingNetLog : public NetLog { |
private: |
CapturingNetLogObserver capturing_net_log_observer_; |
- DISALLOW_COPY_AND_ASSIGN(CapturingNetLog); |
+ DISALLOW_COPY_AND_ASSIGN(TestNetLog); |
}; |
// Helper class that exposes a similar API as BoundNetLog, but uses a |
// CapturingNetLog rather than the more generic NetLog. |
// |
// A CapturingBoundNetLog can easily be converted to a BoundNetLog using the |
// bound() method. |
@@ -56,23 +56,22 @@ class CapturingBoundNetLog { |
BoundNetLog bound() const { return net_log_; } |
// Fills |entry_list| with all entries in the log. |
- void GetEntries(CapturingNetLog::CapturedEntryList* entry_list) const; |
+ void GetEntries(TestNetLog::CapturedEntryList* entry_list) const; |
// Fills |entry_list| with all entries in the log from the specified Source. |
- void GetEntriesForSource( |
- NetLog::Source source, |
- CapturingNetLog::CapturedEntryList* entry_list) const; |
+ void GetEntriesForSource(NetLog::Source source, |
+ TestNetLog::CapturedEntryList* entry_list) const; |
// Returns number of entries in the log. |
size_t GetSize() const; |
void Clear(); |
// Sets the log level of the underlying CapturingNetLog. |
void SetLogLevel(NetLog::LogLevel log_level); |
private: |
- CapturingNetLog capturing_net_log_; |
+ TestNetLog capturing_net_log_; |
const BoundNetLog net_log_; |
DISALLOW_COPY_AND_ASSIGN(CapturingBoundNetLog); |
@@ -16,17 +16,17 @@ |
namespace net { |
-// CapturingNetLog is convenience class which combines a NetLog and a |
+// TestNetLog is convenience class which combines a NetLog and a |
// CapturingNetLogObserver. It is intended for testing only, and is part of the |
// net_test_support project. |
@@ -39,11 +39,11 @@ class CapturingNetLog : public NetLog { |
}; |
// Helper class that exposes a similar API as BoundNetLog, but uses a |
-// CapturingNetLog rather than the more generic NetLog. |
+// TestNetLog rather than the more generic NetLog. |
// |
// A CapturingBoundNetLog can easily be converted to a BoundNetLog using the |
@@ -56,23 +56,22 @@ class CapturingBoundNetLog { |
size_t GetSize() const; |
void Clear(); |
- // Sets the log level of the underlying CapturingNetLog. |
+ // Sets the log level of the underlying TestNetLog. |
void SetLogLevel(NetLog::LogLevel log_level); |
private: |